changeset 31:598d93a7fe72

Added rcsid
author neelin <neelin>
date Tue, 01 Dec 1992 14:04:42 +0000
parents 6bc57dcfcd0c
children 95d44e26fede
files libsrc/minc_basic.h libsrc/minc_private.h libsrc/minc_routines.h libsrc/minc_structures.h libsrc/minc_useful.h libsrc/minc_varlists.h libsrc/type_limits.h
diffstat 7 files changed, 19 insertions(+), 14 deletions(-) [+]
line wrap: on
line diff
--- a/libsrc/minc_basic.h
+++ b/libsrc/minc_basic.h
@@ -13,6 +13,7 @@
 @CALLS      : 
 @CREATED    : August 28, 1992 (Peter Neelin)
 @MODIFIED   : 
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_basic.h,v 1.4 1992-12-01 14:04:42 neelin Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 /* --------- MINC specific constants ------------- */
@@ -31,9 +32,6 @@
 #define MI_PRIV_GET 10
 #define MI_PRIV_PUT 11
 
-/* Number of image dimensions for image conversion */
-#define MI_PRIV_IMGDIMS 2
-
 /* Suffix for dimension width variable names */
 #define MI_WIDTH_SUFFIX "-width"
 
--- a/libsrc/minc_private.h
+++ b/libsrc/minc_private.h
@@ -13,6 +13,7 @@
 @CALLS      : 
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_private.h,v 1.3 1992-12-01 14:04:50 neelin Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 #include  <stdlib.h>
--- a/libsrc/minc_routines.h
+++ b/libsrc/minc_routines.h
@@ -12,6 +12,7 @@
 @CALLS      : 
 @CREATED    : August 28, 1992 (Peter Neelin)
 @MODIFIED   : 
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_routines.h,v 1.5 1992-12-01 14:04:53 neelin Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 /* MINC routines that should only be visible to the package (semiprivate) */
--- a/libsrc/minc_useful.h
+++ b/libsrc/minc_useful.h
@@ -15,9 +15,9 @@
 @CREATED    : July 15, 1991       David MacDonald
 @MODIFIED   : July 29, 1992       Peter Neelin
                  - changed name for MINC routines and added some macros
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_useful.h,v 1.3 1992-12-01 14:04:58 neelin Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
-
 /* --------- define the prefixes to all functions ---------- */
 
 #ifndef public
--- a/libsrc/minc_varlists.h
+++ b/libsrc/minc_varlists.h
@@ -5,7 +5,9 @@
 @METHOD     : Note that lists should be NULL terminated.
 @CREATED    : Peter Neelin (August 7, 1992)
 @MODIFIED   : 
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_varlists.h,v 1.2 1992-12-01 14:04:59 neelin Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
+
 /* Variables containing list of standard dimension names and variable names */
 
 /* List of dimension variables. Note that MIvector_dimension is not included
--- a/libsrc/type_limits.h
+++ b/libsrc/type_limits.h
@@ -5,6 +5,7 @@
 @METHOD     : 
 @CREATED    : August 7, 1992 (Peter Neelin)
 @MODIFIED   : 
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/type_limits.h,v 1.2 1992-12-01 14:05:02 neelin Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 #include <limits.h>
--- a/libsrc/minc_structures.h
+++ b/libsrc/minc_structures.h
@@ -12,6 +12,7 @@
 @CALLS      : 
 @CREATED    : August 28, 1992 (Peter Neelin)
 @MODIFIED   : 
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_structures.h,v 1.5 1992-12-01 14:04:55 neelin Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 /* Image conversion variable structure type */
@@ -52,7 +53,8 @@
    int     user_xdim_dir;  /* Direction for x, y and z dimensions */
    int     user_ydim_dir;
    int     user_zdim_dir;
-   long    user_dim_size[MI_PRIV_IMGDIMS]; /* Size of fastest varying 
+   int     user_num_imgdims; /* Number of image (fastest varying) dimensions */
+   long    user_dim_size[MI_MAX_IMGDIMS]; /* Size of fastest varying 
                                               dimensions for user */
    int     user_keep_aspect; /* Indicates that user wants to preserve the
                                 aspect ratio when resizing images */
@@ -71,7 +73,7 @@
    double  var_vmin;
    int     var_is_vector;  /* Is this variable a vector field */
    long    var_vector_size; /* Size of vector dimension */
-   long    var_dim_size[MI_PRIV_IMGDIMS]; /* Size of image dimensions in 
+   long    var_dim_size[MI_MAX_IMGDIMS]; /* Size of image dimensions in 
                                              variable */
 
    /* Fields derived from user values and variable values */
@@ -99,20 +101,20 @@
    long    derv_icv_start[MAX_VAR_DIMS]; /* Space for storing parameters to */
    long    derv_icv_count[MAX_VAR_DIMS]; /* MI_icv_access */
 
                            /* Stuff that affects first MI_PRIV_IMGDIMS 
                               (excluding any vector dimension) as image
                               dimensions */
-   int     derv_dim_flip[MI_PRIV_IMGDIMS];   /* Flip dimension? */
-   int     derv_dim_grow[MI_PRIV_IMGDIMS];   /* Expand variable to fit user's 
+   int     derv_dim_flip[MI_MAX_IMGDIMS];   /* Flip dimension? */
+   int     derv_dim_grow[MI_MAX_IMGDIMS];   /* Expand variable to fit user's 
                                                 array? */
-   int     derv_dim_scale[MI_PRIV_IMGDIMS];  /* Grow/shrink scale factor */
-   int     derv_dim_off[MI_PRIV_IMGDIMS];    /* Pixels to skip in user's 
+   int     derv_dim_scale[MI_MAX_IMGDIMS];  /* Grow/shrink scale factor */
+   int     derv_dim_off[MI_MAX_IMGDIMS];    /* Pixels to skip in user's 
                                                 image */
-   double  derv_dim_step[MI_PRIV_IMGDIMS];   /* Step, start for user's image 
+   double  derv_dim_step[MI_MAX_IMGDIMS];   /* Step, start for user's image 
                                                 (analogous to MIstep, 
                                                 MIstart) for first 
-                                                MI_PRIV_IMGDIMS dims */
-   double  derv_dim_start[MI_PRIV_IMGDIMS];
+                                                user_num_imgdims dims */
+   double  derv_dim_start[MI_MAX_IMGDIMS];
 };
 
 /* Structure for passing values for MI_varaccess */
@@ -99,20 +101,20 @@
    long    derv_icv_count[MAX_VAR_DIMS]; /* MI_icv_access */
 
-                           /* Stuff that affects first MI_PRIV_IMGDIMS 
+                           /* Stuff that affects first user_num_imgdims
                               (excluding any vector dimension) as image
                               dimensions */